ZeroTrieBuildError

Enum ZeroTrieBuildError 

#[non_exhaustive]
pub enum ZeroTrieBuildError { NonAsciiError, CapacityExceeded, CouldNotSolvePerfectHash, MixedCase, IllegalDelimiter, }
Error types for the zerotrie crate.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NonAsciiError

Non-ASCII data was added to an ASCII-only trie.



CapacityExceeded

The trie reached its maximum supported capacity.



CouldNotSolvePerfectHash

The builder could not solve the perfect hash function.



MixedCase

Mixed-case data was added to a case-insensitive trie.



IllegalDelimiter

Strings were added to a trie containing the delimiter.

Examples

use std::collections::BTreeMap;
use zerotrie::dense::ZeroAsciiDenseSparse2dTrieOwned;
use zerotrie::ZeroTrieBuildError;

let mut data: BTreeMap<&str, BTreeMap<&str, usize>> = BTreeMap::new();

// Delimiter in a prefix
data.entry("aa/bb").or_default().insert("CCC", 1);
let err =
    ZeroAsciiDenseSparse2dTrieOwned::try_from_btree_map_str(&data, b'/')
        .unwrap_err();
assert_eq!(err, ZeroTrieBuildError::IllegalDelimiter);

// Delimiter in a suffix
data.clear();
data.entry("aaa").or_default().insert("BB/CC", 1);
let err =
    ZeroAsciiDenseSparse2dTrieOwned::try_from_btree_map_str(&data, b'/')
        .unwrap_err();
assert_eq!(err, ZeroTrieBuildError::IllegalDelimiter);